==> dhall-javagen_3-0.9.0-M2-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"api/index.html","n":"API","t":" API","d":"api"},
{"l":"api/org/dhallj/javagen.html","n":"org.dhallj.javagen","t":"package org.dhallj.javagen","d":"org/dhallj/javagen"},
{"l":"api/org/dhallj/javagen.html","n":"toJavaCode","t":"def toJavaCode(expr: Expr, packageName: String, className: String): String","d":"org/dhallj/javagen"},
{"l":"api/org/dhallj/javagen/Code.html","n":"Code","t":"class Code(content: String, defs: Vector[Code])","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"mapContent","t":"def mapContent(f: String => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"merge","t":"def merge(other: Code)(f: (String, String) => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"merge","t":"def merge(other0: Code, other1: Code)(f: (String, String, String) => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"toClassDef","t":"def toClassDef(packageName: String, className: String): String","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"Code","t":"object Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"mergeAll","t":"def mergeAll(other: Vector[Code])(f: Vector[String] => String): Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"mergeAll","t":"def mergeAll[A](other: Vector[A])(extract: A => Option[Code])(f: Vector[(A, String)] => String): Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor$.html","n":"ToCodeVisitor","t":"object ToCodeVisitor","d":"org/dhallj/javagen/ToCodeVisitor$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor$.html","n":"instance","t":"val instance: Visitor[Code]","d":"org/dhallj/javagen/ToCodeVisitor$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"ToCodeVisitor","t":"class ToCodeVisitor extends NoPrepareEvents[Code]","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNote","t":"def onNote(base: Code, source: Source): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNatural","t":"def onNatural(self: Expr, value: BigInteger): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onInteger","t":"def onInteger(self: Expr, value: BigInteger): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onDouble","t":"def onDouble(self: Expr, value: Double): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onBuiltIn","t":"def onBuiltIn(self: Expr, name: String): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onIdentifier","t":"def onIdentifier(self: Expr, name: String, index: Long): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLambda","t":"def onLambda(name: String, tpe: Code, result: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onPi","t":"def onPi(name: String, tpe: Code, result: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLet","t":"def onLet(bindings: List[LetBinding[Code]], body: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onText","t":"def onText(parts: Array[String], interpolated: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNonEmptyList","t":"def onNonEmptyList(values: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onEmptyList","t":"def onEmptyList(tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRecord","t":"def onRecord(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRecordType","t":"def onRecordType(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onUnionType","t":"def onUnionType(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onFieldAccess","t":"def onFieldAccess(base: Code, fieldName: String): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onProjection","t":"def onProjection(base: Code, fieldNames: Array[String]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onProjectionByType","t":"def onProjectionByType(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onApplication","t":"def onApplication(base: Code, args: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onOperatorApplication","t":"def onOperatorApplication(operator: Operator, lhs: Code, rhs: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onIf","t":"def onIf(predicate: Code, thenValue: Code, elseValue: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onAnnotated","t":"def onAnnotated(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onAssert","t":"def onAssert(base: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onMerge","t":"def onMerge(handlers: Code, union: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onToMap","t":"def onToMap(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onWith","t":"def onWith(base: Code, path: Array[String], value: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onMissingImport","t":"def onMissingImport(mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onEnvImport","t":"def onEnvImport(value: String, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLocalImport","t":"def onLocalImport(path: Path, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onClasspathImport","t":"def onClasspathImport(path: Path, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRemoteImport","t":"def onRemoteImport(url: URI, using: Code, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/index.html","n":"API","t":" API","d":"api"}];

==> dhall-javagen_3-0.10.0-M2-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"api/index.html","n":"API","t":" API","d":"api"},
{"l":"api/org/dhallj/javagen.html","n":"org.dhallj.javagen","t":"package org.dhallj.javagen","d":"org/dhallj/javagen"},
{"l":"api/org/dhallj/javagen.html","n":"toJavaCode","t":"def toJavaCode(expr: Expr, packageName: String, className: String): String","d":"org/dhallj/javagen"},
{"l":"api/org/dhallj/javagen/Code.html","n":"Code","t":"class Code(content: String, defs: Vector[Code])","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"mapContent","t":"def mapContent(f: String => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"merge","t":"def merge(other: Code)(f: (String, String) => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"merge","t":"def merge(other0: Code, other1: Code)(f: (String, String, String) => String): Code","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code.html","n":"toClassDef","t":"def toClassDef(packageName: String, className: String): String","d":"org/dhallj/javagen/Code"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"Code","t":"object Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"mergeAll","t":"def mergeAll(other: Vector[Code])(f: Vector[String] => String): Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/Code$.html","n":"mergeAll","t":"def mergeAll[A](other: Vector[A])(extract: A => Option[Code])(f: Vector[(A, String)] => String): Code","d":"org/dhallj/javagen/Code$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor$.html","n":"ToCodeVisitor","t":"object ToCodeVisitor","d":"org/dhallj/javagen/ToCodeVisitor$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor$.html","n":"instance","t":"val instance: Visitor[Code]","d":"org/dhallj/javagen/ToCodeVisitor$"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"ToCodeVisitor","t":"class ToCodeVisitor extends NoPrepareEvents[Code]","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNote","t":"def onNote(base: Code, source: Source): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNatural","t":"def onNatural(self: Expr, value: BigInteger): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onInteger","t":"def onInteger(self: Expr, value: BigInteger): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onDouble","t":"def onDouble(self: Expr, value: Double): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onDate","t":"def onDate(self: Expr, year: Int, month: Int, day: Int): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onTime","t":"def onTime(self: Expr, hour: Int, minute: Int, second: Int, fractional: BigDecimal): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onTimeZone","t":"def onTimeZone(self: Expr, seconds: Int): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onBuiltIn","t":"def onBuiltIn(self: Expr, name: String): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onIdentifier","t":"def onIdentifier(self: Expr, name: String, index: Long): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLambda","t":"def onLambda(name: String, tpe: Code, result: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onPi","t":"def onPi(name: String, tpe: Code, result: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLet","t":"def onLet(bindings: List[LetBinding[Code]], body: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onText","t":"def onText(parts: Array[String], interpolated: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onNonEmptyList","t":"def onNonEmptyList(values: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onEmptyList","t":"def onEmptyList(tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRecord","t":"def onRecord(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRecordType","t":"def onRecordType(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onUnionType","t":"def onUnionType(fields: List[Entry[String, Code]]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onFieldAccess","t":"def onFieldAccess(base: Code, fieldName: String): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onProjection","t":"def onProjection(base: Code, fieldNames: Array[String]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onProjectionByType","t":"def onProjectionByType(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onApplication","t":"def onApplication(base: Code, args: List[Code]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onOperatorApplication","t":"def onOperatorApplication(operator: Operator, lhs: Code, rhs: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onIf","t":"def onIf(predicate: Code, thenValue: Code, elseValue: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onAnnotated","t":"def onAnnotated(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onAssert","t":"def onAssert(base: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onMerge","t":"def onMerge(handlers: Code, union: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onToMap","t":"def onToMap(base: Code, tpe: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onWith","t":"def onWith(base: Code, path: Array[String], value: Code): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onMissingImport","t":"def onMissingImport(mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onEnvImport","t":"def onEnvImport(value: String, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onLocalImport","t":"def onLocalImport(path: Path, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onClasspathImport","t":"def onClasspathImport(path: Path, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/org/dhallj/javagen/ToCodeVisitor.html","n":"onRemoteImport","t":"def onRemoteImport(url: URI, using: Code, mode: ImportMode, hash: Array[Byte]): Code","d":"org/dhallj/javagen/ToCodeVisitor"},
{"l":"api/index.html","n":"API","t":" API","d":"api"}];
